@@ -26,9 +26,7 @@
 
 /* these includes are needed for Qt support */
 #include <QApplication>
-#include <QGridLayout>
 #include <QIntValidator>
-#include <QLabel>
 #include <QLayout>
 #include <QLineEdit>
 #include <QLocale>
